Struct

MalcontentAppFilter

since: 0.2.0

Description [src]

struct MctAppFilter {
  /* No available fields */
}

An opaque, immutable structure which contains a snapshot of the app filtering settings for a user at a given time.

This includes a list of apps which are explicitly banned or allowed to be run by that user.

Typically, app filter settings can only be changed by the administrator, and are read-only for non-administrative users. The precise policy is set using polkit.

Available since: 0.2.0

Functions

mct_app_filter_deserialize

Deserialize an app filter previously serialized with mct_app_filter_serialize().

since: 0.7.0

mct_app_filter_error_quark

Error quark aliased to MctManagerError.

since: 0.2.0

Instance methods

mct_app_filter_equal

Check whether app filters a and b are equal.

since: 0.10.0

mct_app_filter_get_oars_sections

List the OARS sections present in this app filter.

since: 0.2.0

mct_app_filter_get_oars_value

Get the value assigned to the given oars_section in the OARS filter stored within filter.

since: 0.2.0

mct_app_filter_get_user_id

Get the user ID of the user this app filter is for.

since: 0.2.0

mct_app_filter_is_appinfo_allowed

Check whether the app with the given app_info is allowed to be run according to this app filter.

since: 0.2.0

mct_app_filter_is_content_type_allowed

Check whether apps handling the given content_type are allowed to be run according to this app filter.

since: 0.4.0

mct_app_filter_is_enabled

Check whether the app filter is enabled and is going to impose at least one restriction on the user.

since: 0.7.0

mct_app_filter_is_flatpak_app_allowed

Check whether the flatpak app with the given app_id is allowed to be run according to this app filter.

since: 0.2.0

mct_app_filter_is_flatpak_ref_allowed

Check whether the flatpak app with the given app_ref is allowed to be run according to this app filter.

since: 0.2.0

mct_app_filter_is_path_allowed

Check whether the program at path is allowed to be run according to this app filter.

since: 0.2.0

mct_app_filter_is_system_installation_allowed

Get whether the user is allowed to install to the flatpak system repository.

since: 0.2.0

mct_app_filter_is_user_installation_allowed

Get whether the user is allowed to install to their flatpak user repository.

since: 0.2.0

mct_app_filter_ref

Increment the reference count of filter, and return the same pointer to it.

since: 0.2.0

mct_app_filter_serialize

Build a GVariant which contains the app filter from filter, in an opaque variant format.

since: 0.7.0

mct_app_filter_unref

Decrement the reference count of filter. If the reference count reaches zero, free the filter and all its resources.

since: 0.2.0